use std::str::FromStr;

use crate::app::App;
use crate::theme::onedark::ONE_DARK;

use subnet_calculator::{Network, ip::IpAddr, NetworkingErr};

impl eframe::App for App {
    fn update(&mut self, ctx: &egui::Context, _frame: &mut eframe::Frame) {
        let background_frame = egui::Frame::default().fill(ONE_DARK.bg);
        
        egui::CentralPanel::default()
        .frame(background_frame)
        .show(ctx, |_| {
            egui::SidePanel::left("my_panel").show(ctx, |ui| {
                ui.heading(&self.name);
            });

            egui::CentralPanel::default().show(ctx, |ui| -> Result<(), NetworkingErr>{
                ui.heading(&self.name);
                ui.text_edit_singleline(&mut self.ip);
                ui.text_edit_singleline(&mut self.cidr);

                if ui.button(String::from("Calculate Subnet")).clicked() {
                    let ip_addr: IpAddr = IpAddr::from_str(self.ip.as_str())?;
                    let cidr: u8 = u8::from_str(self.cidr.as_str()).unwrap_or(24);
                    println!("{:?}", Network::create_subnet(&ip_addr, cidr)?);
                }

                Ok(())
            });
        });
    }
}
